from hiddifypanel.panel.restapi.tgbot import  bot,register_bot

from . import Usage
from . import information
from . import admin
from . import DefaultResponse